# 🗿✂️📄 Kanobu
## 🗣 Localisation
| Language         | Status    | Language        | Status    |
|------------------|-----------|-----------------|-----------|
| 🇷🇺 Russian       | 👍 stable | 🇩🇪 German        | ⚠️ beta    |
| 🇺🇦 Ukrainian     | 👍 stable | 🇬🇧 English       | 👍 stable  |
| 🇫🇷 French        | ⚠️ beta   | 🇪🇸 Spanish       | 🗓 plans   |
| 🇵🇹 Portuguese    | 🗓 plans  | 🇺🇸 English (USA) | ⚠️ beta    |
| 🇵🇱 Polish        | 🗓 plans  | 🇮🇹 Italian       | ⚠️ beta    |
| 🇭🇺 Hungarian     | 🗓 plans  | 😀 Emoji         | ⚠️ beta    |

## 🚀 Start
To start, run this code:
```
pip install kanobu
kanobu
```
## ⚙️ Options
| Option    | Information                                                                |
|-----------|----------------------------------------------------------------------------|
| `dev`     | To get developers functions, and logs about variables and other parameters |
| `lang`    | For set default language. All languages placed in locale folder            |
| `version` | option to display the version                                              |
| `choise`  | For enter choice without `input()`                                         |

## 🔨 Dependencies
### 🖌 [colorama](https://github.com/tartley/colorama)
Simple cross-platform colored terminal text in Python. Support `cmd`, `bash`
### 📄 [pyyaml](https://github.com/yaml/pyyaml)
The next generation YAML parser and emitter for Python.
